kPAL (*k*-mer profile analysis library)
=======================================

kPAL is an analysis toolkit and Python programming library for *k*-mer
profiles.


Easy installation
-----------------

To install the latest release via PyPI using pip::

    pip install kPAL

See the documentation for more detailed `installation instructions
<http://kpal.readthedocs.org/en/latest/install.html>`_.


Documentation
-------------

The `kPAL documentation <http://kpal.readthedocs.org/>`_ with user guide and
API reference is hosted at Read The Docs.


Copyright
---------

kPAL is licensed under the MIT License, see the LICENSE.rst file for
details. See the AUTHORS.rst file for a list of authors.


.. _Sphinx: http://sphinx-doc.org/
